<?php

namespace Schaffen\Gef\Http\Controllers;

use App\Http\Controllers\Controller;
use App\Http\Utils\Response;
use Illuminate\Http\Request;

use Schaffen\Gef\Http\Requests;
use Prettus\Service\Contracts\ServiceInterface;
use Prettus\Service\Exceptions\ServiceException;
use Schaffen\Gef\Http\Requests\ApontamentoVeiculoGastoCreateRequest;
use Schaffen\Gef\Http\Requests\ApontamentoVeiculoGastoUpdateRequest;
use Schaffen\Gef\Models\ApontamentoVeiculoGasto;
use Schaffen\Gef\Repositories\ApontamentoVeiculoGastoRepository;
use Schaffen\Gef\Services\ApontamentoVeiculoGastoService;

/**
 * Class ApontamentoVeiculoGastosController.
 *
 * @package namespace Schaffen\Gef\Http\Controllers;
 */
class ApontamentoVeiculoGastosController extends Controller
{
   /**
    * @var ApontamentoVeiculoGastoRepository
    */
   protected $repository;

   /**
    * @var ApontamentoVeiculoGastoService
    */
   protected $service;

   /**
    * ApontamentoVeiculoGastosController constructor.
    *
    * @param ApontamentoVeiculoGastoRepository $repository
    * @param ApontamentoVeiculoGastoService $service
    */
   public function __construct(ApontamentoVeiculoGastoRepository $repository, ApontamentoVeiculoGastoService $service)
   {
      $this->repository = $repository;
      $this->service = $service;
   }

   public function getConsumiveis()
   {
      $this->repository->pushCriteria(new \Schaffen\Gef\Criterias\ApontamentosComConsumiveisCriteria());
      $apontamento_veiculo_gasto = $this->repository->all();

      $ret['cols'] = array();
      array_push($ret['cols'], ['field' => "codigo", 'title' => "Código", 'dataType' => 'id', 'filter' => ['codigo' => "text"], 'sortable' => "codigo", 'show' => true]);
      array_push($ret['cols'], ['field' => "descricao", 'title' => "Descricao", 'dataType' => 'text', 'filter' => ['descricao' => "text"], 'sortable' => "descricao", 'show' => true]);
      array_push($ret['cols'], ['field' => "responsavel", 'title' => "Responsavel", 'dataType' => 'text', 'filter' => ['responsavel' => "text"], 'sortable' => "responsavel", 'show' => true]);
      array_push($ret['cols'], ['field' => "veiculo", 'title' => "Veiculo", 'dataType' => 'text', 'filter' => ['veiculo' => "text"], 'sortable' => "veiculo", 'show' => true]);
      array_push($ret['cols'], ['field' => "action", 'title' => "Opções", 'dataType' => 'command', 'show' => true]);

      $ret['rows'] = $apontamento_veiculo_gasto["data"];

      return response()->json([
         'data' => $ret,
      ]);
   }
   public function getAcessorios()
   {

      $this->repository->pushCriteria(new \Schaffen\Gef\Criterias\ApontamentosComAcessoriosCriteria());
      $apontamento_veiculo_gasto = $this->repository->all();

      $ret['cols'] = array();
      array_push($ret['cols'], ['field' => "codigo", 'title' => "Código", 'dataType' => 'id', 'filter' => ['codigo' => "text"], 'sortable' => "codigo", 'show' => true]);
      array_push($ret['cols'], ['field' => "descricao", 'title' => "Descricao", 'dataType' => 'text', 'filter' => ['descricao' => "text"], 'sortable' => "descricao", 'show' => true]);
      array_push($ret['cols'], ['field' => "responsavel", 'title' => "Responsavel", 'dataType' => 'text', 'filter' => ['responsavel' => "text"], 'sortable' => "responsavel", 'show' => true]);
      array_push($ret['cols'], ['field' => "veiculo", 'title' => "Veiculo", 'dataType' => 'text', 'filter' => ['veiculo' => "text"], 'sortable' => "veiculo", 'show' => true]);
      array_push($ret['cols'], ['field' => "action", 'title' => "Opções", 'dataType' => 'command', 'show' => true]);

      $ret['rows'] = $apontamento_veiculo_gasto["data"];

      return response()->json([
         'data' => $ret,
      ]);
   }

   /**
    * Display a listing of the resource.
    *
    * @return \Illuminate\Http\Response
    */
   public function index(Request $request)
   {
      $this->repository->pushCriteria(new \Schaffen\Gef\Criterias\RequestPrefixCriteria($request, ApontamentoVeiculoGasto::$prefix));
      $apontamento_veiculo_gasto = $this->repository->all();

      $ret['cols'] = array();
      array_push($ret['cols'], ['field' => "codigo", 'title' => "Código", 'dataType' => 'id', 'filter' => ['codigo' => "text"], 'sortable' => "codigo", 'show' => true]);
      array_push($ret['cols'], ['field' => "descricao", 'title' => "Descricao", 'dataType' => 'text', 'filter' => ['descricao' => "text"], 'sortable' => "descricao", 'show' => true]);
      array_push($ret['cols'], ['field' => "responsavel", 'title' => "Responsavel", 'dataType' => 'text', 'filter' => ['responsavel' => "text"], 'sortable' => "responsavel", 'show' => true]);
      array_push($ret['cols'], ['field' => "veiculo", 'title' => "Veiculo", 'dataType' => 'text', 'filter' => ['veiculo' => "text"], 'sortable' => "veiculo", 'show' => true]);
      array_push($ret['cols'], ['field' => "action", 'title' => "Opções", 'dataType' => 'command', 'show' => true]);
      $ret['rows'] = $apontamento_veiculo_gasto["data"];

      return response()->json([
         'data' => $ret,
      ]);

   }

   /**
    * Store a newly created resource in storage.
    *
    * @param  ApontamentoVeiculoGastoCreateRequest $request
    *
    * @return \Illuminate\Http\Response
    *
    * @throws \Prettus\Service\Exceptions\ServiceException
    */
   public function store(ApontamentoVeiculoGastoCreateRequest $request)
   {
      $response = $this->service->updateOrCreate($request->all());
      return Response::response($response['status'], $response['message'], $response['data'], $response['errors'], $response['http_code']);
   }

   /**
    * Display the specified resource.
    *
    * @param  int $id
    *
    * @return \Illuminate\Http\Response
    */

   public function show($id)
   {
      $this->repository->setPresenter("Schaffen\\Gef\\Presenters\\ApontamentoVeiculoGastoShowPresenter");
      $apontamento_veiculo_gasto = $this->repository->find($id);

      return Response::response(true, null, $apontamento_veiculo_gasto, null);
   }

   /**
    * Show the form for editing the specified resource.
    *
    * @param  int $id
    *
    * @return \Illuminate\Http\Response
    */
   public function edit($id)
   {
      $apontamentoVeiculoGasto = $this->repository->find($id);

      return view('apontamentoVeiculoGastos.edit', compact('apontamentoVeiculoGasto'));
   }

   /**
    * Update the specified resource in storage.
    *
    * @param  ApontamentoVeiculoGastoUpdateRequest $request
    * @param  string $id
    *
    * @return Response
    *
    * @throws \Prettus\Service\Exceptions\ServiceException
    */
   public function update(ApontamentoVeiculoGastoUpdateRequest $request, $id)
   {
      $response = $this->service->updateOrCreate($request->all(), $id);
      return Response::response($response['status'], $response['message'], $response['data'], $response['errors'], $response['http_code']);
   }


   /**
    * Remove the specified resource from storage.
    *
    * @param  int $id
    *
    * @return \Illuminate\Http\Response
    */
   public function destroy($id)
   {
      $deleted = $this->repository->delete($id);

      if (request()->wantsJson()) {

         return response()->json([
            'message' => 'ApontamentoVeiculoGasto deleted.',
            'deleted' => $deleted,
         ]);
      }

      return redirect()->back()->with('message', 'ApontamentoVeiculoGasto deleted.');
   }
}
